@@ -43,7 +43,10 @@ create_validation_step <- function(agent,
       list(
         assertion_type = assertion_type,
         column = ifelse(is.null(column), list(NULL), list(column)),
-        values = ifelse(is.null(values), list(NULL), list(values)),
+        values = ifelse(
+          is.null(values) || is_a_table_object(values),
+          list(NULL), list(values)
+        ),
         na_pass = ifelse(is.null(na_pass), NA, as.logical(na_pass)),
         preconditions = ifelse(
           is.null(preconditions), list(NULL), list(preconditions)
@@ -430,6 +433,18 @@ create_autobrief <- function(agent,
     autobrief <- finalize_autobrief(expectation_text, precondition_text) 
   }
   
+  if (assertion_type == "row_count_match") {
+    
+    expectation_text <- prep_row_count_match_expectation_text(lang = lang)
+    autobrief <- finalize_autobrief(expectation_text, precondition_text) 
+  }
+  
+  if (assertion_type == "tbl_match") {
+    
+    expectation_text <- prep_tbl_match_expectation_text(lang = lang)
+    autobrief <- finalize_autobrief(expectation_text, precondition_text) 
+  }
+  
   if (finalize_serially_brief) {
     
     serially_test_text <-
@@ -534,7 +549,7 @@ prep_column_computed_text <- function(agent,
                                       column,
                                       lang) {
   
-  if (is.null(column)) return("")
+  if (is.null(column) || is.null(agent$col_names)) return("")
   
   column_is_computed <- ifelse(column %in% agent$col_names, FALSE, TRUE)
   
@@ -760,6 +775,16 @@ prep_col_schema_match_expectation_text <- function(lang) {
   glue::glue(get_lsv("autobriefs/col_schema_match_expectation_text")[[lang]])
 }
 
+prep_row_count_match_expectation_text <- function(lang) {
+  
+  glue::glue(get_lsv("autobriefs/row_count_match_expectation_text")[[lang]])
+}
+
+prep_tbl_match_expectation_text <- function(lang) {
+  
+  glue::glue(get_lsv("autobriefs/tbl_match_expectation_text")[[lang]])
+}
+
 prep_col_vals_expr_expectation_text <- function(lang) {
   
   glue::glue(get_lsv("autobriefs/col_vals_expr_expectation_text")[[lang]])
@@ -776,6 +801,8 @@ failure_message_gluestring <- function(fn_name,
   
   # nolint start
   
+  # TODO: Add all missing entries for failure text
+  
   failure_text <- 
     switch(
       fn_name,
@@ -805,7 +832,9 @@ failure_message_gluestring <- function(fn_name,
       "expect_col_is_factor" = get_lsv("autobriefs/col_is_failure_text")[[lang]],
       "expect_rows_distinct" = get_lsv("autobriefs/all_row_distinct_failure_text")[[lang]],
       "expect_rows_complete" = get_lsv("autobriefs/all_row_complete_failure_text")[[lang]],
-      "expect_col_schema_match" = get_lsv("autobriefs/col_schema_match_failure_text")[[lang]]
+      "expect_col_schema_match" = get_lsv("autobriefs/col_schema_match_failure_text")[[lang]],
+      "expect_row_count_match" = get_lsv("autobriefs/row_count_match_failure_text")[[lang]],
+      "expect_tbl_match" = get_lsv("autobriefs/tbl_match_failure_text")[[lang]]
     )
   
   # nolint end
