@@ -160,6 +160,8 @@ get_dbi_column_mean <- function(data_column) {
   x
 }
 
+# nocov start
+
 # Get the mean value of a column in a table
 # - works only with `tbl_spark` objects
 # - returns 'numeric' of length 1
@@ -168,6 +170,8 @@ get_spark_column_mean <- function(data_column) {
   get_dbi_column_mean(data_column = data_column)
 }
 
+# nocov end
+
 # Get the variance value of a column in a table, after obtaining the mean value
 # - works only with `tbl_dbi` objects
 # - returns 'numeric' of length 1
@@ -182,6 +186,8 @@ get_dbi_column_variance <- function(data_column, mean_value) {
   x
 }
 
+# nocov start
+
 # Get the variance value of a column in a table, after obtaining the mean value
 # - works only with `tbl_spark` objects
 # - returns 'numeric' of length 1
@@ -220,6 +226,8 @@ get_spark_column_qtile_stats <- function(data_column) {
     lapply(FUN = function(x) round(x, 2))
 }
 
+# nocov end
+
 # Get a list of quantile statistics for a DBI table column
 # (must be a table with a single column)
 # - works only with `tbl_dbi` objects
@@ -326,10 +334,9 @@ get_table_column_histogram <- function(data_column, lang, locale) {
       dplyr::filter(!is.na(nchar)) %>%
       dplyr::mutate_all(.funs = as.numeric) %>%
       ggplot2::ggplot(ggplot2::aes(x = nchar, y = n)) +
-      ggplot2::geom_col(fill = "steelblue") +
+      ggplot2::geom_col(fill = "steelblue", width = 0.5) +
       ggplot2::geom_hline(yintercept = 0, color = "#B2B2B2") +
       ggplot2::labs(x = x_label, y = y_label) +
-      ggplot2::scale_x_continuous(limits = c(0, NA)) +
       ggplot2::scale_y_continuous(labels = scales::comma_format()) +
       ggplot2::theme_minimal()
   )
@@ -418,6 +425,8 @@ get_tbl_dbi_missing_tbl <- function(data) {
     dplyr::mutate(col_name = factor(col_name, levels = colnames(data)))
 }
 
+# nocov start
+
 # Get a tibble of binned missing value proportions for a table
 # - works only with `tbl_spark` objects
 # - returns 'tibble' of 20 bins * y columns rows, 4 columns
@@ -426,6 +435,8 @@ get_tbl_spark_missing_tbl <- function(data) {
   get_tbl_dbi_missing_tbl(data = data)
 }
 
+# nocov end
+
 # Get a tibble of binned missing value proportions for a table
 # - works only with data frame objects
 # - returns 'tibble' of 20 bins * y columns rows, 4 columns
@@ -538,6 +549,8 @@ get_missing_by_column_tbl <- function(data) {
   missing_by_column_tbl
 }
 
+# nocov start
+
 # Get a ggplot2 plot of missing values by column (with up to 20 bins),
 # supported by the `frequency_tbl` and `missing_by_column_tbl` objects
 # - works across all supported data sources
@@ -612,3 +625,30 @@ get_table_slice_gt <- function(data_column,
       table.width = "100%"
     )
 }
+
+# nocov end
+
+# Get a vector of column labels for a data frame
+# - works only with data frame objects
+# - returns 'character' of length n (NA if label not present or empty)
+get_tbl_df_column_labels <- function(data) {
+  
+  n_columns <- get_table_total_columns(data = data)
+  
+  column_labels <- rep(NA_character_, n_columns)
+  
+  if (!inherits(data, "data.frame")) {
+    return(column_labels)
+  }
+  
+  vapply(
+    data,
+    FUN.VALUE = character(1),
+    USE.NAMES = FALSE,
+    FUN = function(x) {
+      label <- attr(x, "label", exact = TRUE)
+      if (is.null(label)) label <- NA_character_
+      label
+    }
+  )
+}
