@@ -1050,3 +1050,85 @@ test_that("Creating a `rows_distinct()` step is possible", {
   expect_true(is.na(validation$validation_set$notify))
   expect_true(is.na(validation$validation_set$row_sample))
 })
+
+test_that("Creating a `row_count_match()` step is possible", {
+  
+  # Use `row_count_match()` function to create a validation step
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(tbl_compare = small_table)
+  expect_is(validation, "ptblank_agent")
+  
+  # Expect elements of the object to be equivalent
+  # to specific parameters
+  expect_true(inherits(validation$validation_set[["values"]][[1]], "tbl_df"))
+  expect_true(is.na(validation$validation_set$all_passed))
+  expect_true(is.na(validation$validation_set$n))
+  expect_true(is.na(validation$validation_set$n_passed))
+  expect_true(is.na(validation$validation_set$n_failed))
+  expect_true(is.na(validation$validation_set$f_passed))
+  expect_true(is.na(validation$validation_set$f_failed))
+  expect_true(is.na(validation$validation_set$warn))
+  expect_true(is.na(validation$validation_set$notify))
+  expect_true(is.na(validation$validation_set$row_sample))
+  
+  # Use different inputs for `tbl` in `row_count_match()`
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(tbl_compare = ~ small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(tbl_compare = small_table ~ pointblank::small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(tbl_compare = function() small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.function(validation$validation_set[["values"]][[1]]))
+})
+
+test_that("Creating a `tbl_match()` step is possible", {
+  
+  # Use `tbl_match()` function to create a validation step
+  validation <-
+    create_agent(tbl = small_table) %>%
+    tbl_match(tbl_compare = small_table)
+  expect_is(validation, "ptblank_agent")
+  
+  # Expect elements of the object to be equivalent
+  # to specific parameters
+  expect_true(inherits(validation$validation_set[["values"]][[1]], "tbl_df"))
+  expect_true(is.na(validation$validation_set$all_passed))
+  expect_true(is.na(validation$validation_set$n))
+  expect_true(is.na(validation$validation_set$n_passed))
+  expect_true(is.na(validation$validation_set$n_failed))
+  expect_true(is.na(validation$validation_set$f_passed))
+  expect_true(is.na(validation$validation_set$f_failed))
+  expect_true(is.na(validation$validation_set$warn))
+  expect_true(is.na(validation$validation_set$notify))
+  expect_true(is.na(validation$validation_set$row_sample))
+  
+  # Use different inputs for `tbl` in `tbl_match()`
+  validation <-
+    create_agent(tbl = small_table) %>%
+    tbl_match(tbl_compare = ~ small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    tbl_match(tbl_compare = small_table ~ pointblank::small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    tbl_match(tbl_compare = function() small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.function(validation$validation_set[["values"]][[1]]))
+})
