@@ -1022,65 +1022,6 @@ test_that("Interrogating simply returns the expected results", {
   # Expect that `tbl_result` is never created
   expect_false(exists("tbl_result"))
   
-  #
-  # conjointly()
-  #
-  
-  # Use the `conjointly()` function to perform
-  # a conjoint validation validation step directly
-  # on the `tbl` object
-  suppressWarnings(
-    tbl_result <- 
-      tbl %>%
-      conjointly(
-        ~ col_vals_gt(., columns = vars(d), value = 200),
-        ~ col_vals_lt(., columns = vars(c), value = 10),
-        actions = warn_on_fail()
-      )
-  )
-    
-  # Expect that `tbl_result` is equivalent to `tbl`
-  expect_equivalent(tbl, tbl_result)
-  
-  # Perform a simple validation that yields a warning
-  expect_warning(
-    tbl_result <- 
-      tbl %>%
-      conjointly(
-        ~ col_vals_gt(., columns = vars(d), value = 200),
-        ~ col_vals_lt(., columns = vars(c), value = 10),
-        actions = warn_on_fail()
-      )
-  )
-  expect_warning(
-    tbl_result <- 
-      tbl %>%
-      conjointly(
-        ~ col_vals_gt(., columns = vars(d), value = 200),
-        ~ col_vals_lt(., columns = vars(c), value = 10),
-        actions = warn_on_fail()
-      )
-  )
-  
-  # Expect that `tbl_result` is equivalent to `tbl`
-  expect_equivalent(tbl, tbl_result)
-  
-  rm(tbl_result)
-  
-  # Perform a simple validation step that results in stopping
-  expect_error(
-    tbl_result <- 
-      tbl %>%
-      conjointly(
-        ~ col_vals_gt(., columns = vars(d), value = 200),
-        ~ col_vals_lt(., columns = vars(c), value = 10),
-        actions = stop_on_fail()
-      )
-  )
-  
-  # Expect that `tbl_result` is never created
-  expect_false(exists("tbl_result"))
-  
   #
   # rows_distinct()
   #
@@ -1524,6 +1465,171 @@ test_that("Interrogating simply returns the expected results", {
   
   # Expect that `tbl_result` is never created
   expect_false(exists("tbl_result"))
+  
+  #
+  # row_count_match()
+  #
+  
+  # Use the `row_count_match()` function to perform
+  # a simple validation step
+  tbl_result <- 
+    small_table %>%
+    row_count_match(
+      tbl_compare = pointblank::small_table,
+      actions = warn_on_fail()
+    )
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Use the `row_count_match()` function to perform
+  # another simple validation step
+  tbl_result <- 
+    small_table %>%
+    row_count_match(tbl_compare = ~ pointblank::small_table)
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      row_count_match(
+        tbl_compare = pointblank::small_table,
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl_complete_yes`
+  expect_equivalent(tbl_complete_yes, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      row_count_match(
+        tbl_compare = pointblank::small_table,
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is never created
+  expect_false(exists("tbl_result"))
+  
+  #
+  # tbl_match()
+  #
+  
+  # Use the `tbl_match()` function to perform
+  # a simple validation step
+  tbl_result <- 
+    small_table %>%
+    tbl_match(
+      tbl_compare = pointblank::small_table,
+      actions = warn_on_fail()
+    )
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Use the `tbl_match()` function to perform
+  # another simple validation step
+  tbl_result <- 
+    small_table %>%
+    tbl_match(tbl_compare = ~ pointblank::small_table)
+  
+  # Expect that `tbl_result` is equivalent to `small_table`
+  expect_equivalent(small_table, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      tbl_match(
+        tbl_compare = pointblank::small_table,
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl_complete_yes`
+  expect_equivalent(tbl_complete_yes, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl_complete_yes %>%
+      tbl_match(
+        tbl_compare = pointblank::small_table,
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is never created
+  expect_false(exists("tbl_result"))
+  
+  #
+  # conjointly()
+  #
+  
+  # Use the `conjointly()` function to perform
+  # a conjoint validation validation step directly
+  # on the `tbl` object
+  suppressWarnings(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10),
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl`
+  expect_equivalent(tbl, tbl_result)
+  
+  # Perform a simple validation that yields a warning
+  expect_warning(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10),
+        actions = warn_on_fail()
+      )
+  )
+  expect_warning(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10),
+        actions = warn_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is equivalent to `tbl`
+  expect_equivalent(tbl, tbl_result)
+  
+  rm(tbl_result)
+  
+  # Perform a simple validation step that results in stopping
+  expect_error(
+    tbl_result <- 
+      tbl %>%
+      conjointly(
+        ~ col_vals_gt(., columns = vars(d), value = 200),
+        ~ col_vals_lt(., columns = vars(c), value = 10),
+        actions = stop_on_fail()
+      )
+  )
+  
+  # Expect that `tbl_result` is never created
+  expect_false(exists("tbl_result"))
 })
 
 test_that("Interrogating simply incorporates the `na_pass` option", {
