@@ -673,6 +673,95 @@ test_that("pointblank expectation functions produce the correct results", {
       threshold = 0.01
     )
   )
+  
+  #
+  # test_row_count_match()
+  #
+  
+  expect_true(test_row_count_match(tbl, tbl_compare = tbl))
+  expect_true(test_row_count_match(tbl, tbl_compare = pointblank::small_table))
+  expect_true(test_row_count_match(tbl, tbl_compare = ~ pointblank::small_table))
+  expect_true(test_row_count_match(tbl, tbl_compare = function() pointblank::small_table))
+  expect_false(test_row_count_match(tbl, tbl_compare = tbl_conjointly))
+  expect_false(test_row_count_match(tbl_conjointly, tbl_compare = tbl))
+  expect_true(test_row_count_match(tbl_conjointly, tbl_compare = tbl_complete_yes))
+  expect_true(test_row_count_match(tbl_complete_yes, tbl_compare = tbl_conjointly))
+  expect_true(test_row_count_match(tbl_complete_no, tbl_compare = tbl_complete_yes))
+  expect_true(test_row_count_match(tbl_complete_yes, tbl_compare = tbl_complete_no))
+  expect_true(test_row_count_match(increasing_tbl, tbl_compare = decreasing_tbl))
+  expect_true(test_row_count_match(decreasing_tbl, tbl_compare = increasing_tbl))
+  
+  #
+  # test_tbl_match()
+  #
+  
+  expect_true(test_tbl_match(tbl, tbl_compare = tbl))
+  expect_true(test_tbl_match(pointblank::small_table, tbl_compare = pointblank::small_table))
+  expect_true(test_tbl_match(pointblank::small_table, tbl_compare = ~ pointblank::small_table))
+  expect_true(test_tbl_match(pointblank::small_table, tbl_compare = function() pointblank::small_table))
+  expect_true(test_tbl_match(tbl_complete_no, tbl_compare = tbl_complete_no))
+  expect_true(test_tbl_match(tbl_complete_yes, tbl_compare = tbl_complete_yes))
+  expect_true(test_tbl_match(tbl_conjointly, tbl_compare = tbl_conjointly))
+  expect_true(test_tbl_match(increasing_tbl, tbl_compare = increasing_tbl))
+  expect_true(test_tbl_match(decreasing_tbl, tbl_compare = decreasing_tbl))
+  expect_false(test_tbl_match(tbl, tbl_compare = pointblank::small_table))
+  expect_false(test_tbl_match(tbl, tbl_compare = ~ pointblank::small_table))
+  expect_false(test_tbl_match(tbl, tbl_compare = function() pointblank::small_table))
+  expect_false(test_tbl_match(tbl_conjointly, tbl_compare = tbl_complete_yes))
+  expect_false(test_tbl_match(tbl_complete_yes, tbl_compare = tbl_conjointly))
+  expect_false(test_tbl_match(tbl_complete_yes, tbl_compare = tbl_complete_no))
+  
+  expect_true(test_tbl_match(gt::countrypops, tbl_compare = gt::countrypops))
+  expect_true(test_tbl_match(gt::sza, tbl_compare = gt::sza))
+  expect_true(test_tbl_match(gt::gtcars, tbl_compare = gt::gtcars))
+  expect_true(test_tbl_match(gt::sp500, tbl_compare = gt::sp500))
+  expect_true(test_tbl_match(gt::pizzaplace, tbl_compare = gt::pizzaplace))
+  expect_true(test_tbl_match(gt::exibble, tbl_compare = gt::exibble))
+  expect_true(test_tbl_match(ggplot2::diamonds, tbl_compare = ggplot2::diamonds))
+  expect_true(test_tbl_match(ggplot2::economics_long, tbl_compare = ggplot2::economics_long))
+  expect_true(test_tbl_match(ggplot2::faithfuld, tbl_compare = ggplot2::faithfuld))
+  expect_true(test_tbl_match(ggplot2::luv_colours, tbl_compare = ggplot2::luv_colours))
+  expect_true(test_tbl_match(ggplot2::midwest, tbl_compare = ggplot2::midwest))
+  expect_true(test_tbl_match(ggplot2::mpg, tbl_compare = ggplot2::mpg))
+  expect_true(test_tbl_match(ggplot2::msleep, tbl_compare = ggplot2::msleep))
+  expect_true(test_tbl_match(ggplot2::presidential, tbl_compare = ggplot2::presidential))
+  expect_true(test_tbl_match(ggplot2::seals, tbl_compare = ggplot2::seals))
+  expect_true(test_tbl_match(ggplot2::txhousing, tbl_compare = ggplot2::txhousing))
+  expect_true(test_tbl_match(dplyr::band_instruments, tbl_compare = dplyr::band_instruments))
+  expect_true(test_tbl_match(dplyr::band_members, tbl_compare = dplyr::band_members))
+  expect_true(test_tbl_match(dplyr::starwars, tbl_compare = dplyr::starwars))
+  expect_true(test_tbl_match(dplyr::storms, tbl_compare = dplyr::storms))
+  expect_true(test_tbl_match(tidyr::billboard, tbl_compare = tidyr::billboard))
+  expect_true(test_tbl_match(tidyr::construction, tbl_compare = tidyr::construction))
+  expect_true(test_tbl_match(tidyr::fish_encounters, tbl_compare = tidyr::fish_encounters))
+  expect_true(test_tbl_match(tidyr::population, tbl_compare = tidyr::population))
+  expect_true(test_tbl_match(tidyr::relig_income, tbl_compare = tidyr::relig_income))
+  expect_true(test_tbl_match(tidyr::smiths, tbl_compare = tidyr::smiths))
+  expect_true(test_tbl_match(tidyr::us_rent_income, tbl_compare = tidyr::us_rent_income))
+  expect_true(test_tbl_match(tidyr::who, tbl_compare = tidyr::who))
+  expect_true(test_tbl_match(tidyr::world_bank_pop, tbl_compare = tidyr::world_bank_pop))
+  expect_true(test_tbl_match(lubridate::lakers, tbl_compare = lubridate::lakers))
+  expect_true(test_tbl_match(datasets::airquality, tbl_compare = datasets::airquality))
+  expect_true(test_tbl_match(datasets::chickwts, tbl_compare = datasets::chickwts))
+  expect_true(test_tbl_match(datasets::iris, tbl_compare = datasets::iris))
+  expect_true(test_tbl_match(datasets::LifeCycleSavings, tbl_compare = datasets::LifeCycleSavings))
+  expect_true(test_tbl_match(datasets::longley, tbl_compare = datasets::longley))
+  expect_true(test_tbl_match(datasets::morley, tbl_compare = datasets::morley))
+  expect_true(test_tbl_match(datasets::mtcars, tbl_compare = datasets::mtcars))
+  expect_true(test_tbl_match(datasets::Orange, tbl_compare = datasets::Orange))
+  expect_true(test_tbl_match(datasets::pressure, tbl_compare = datasets::pressure))
+  expect_true(test_tbl_match(datasets::quakes, tbl_compare = datasets::quakes))
+  expect_true(test_tbl_match(datasets::rock, tbl_compare = datasets::rock))
+  expect_true(test_tbl_match(datasets::swiss, tbl_compare = datasets::swiss))
+  expect_true(test_tbl_match(datasets::USJudgeRatings, tbl_compare = datasets::USJudgeRatings))
+  
+  expect_false(test_tbl_match(tbl, tbl_compare = tbl %>% dplyr::slice_head(n = 12)))
+  expect_false(test_tbl_match(tbl, tbl_compare = tbl %>% dplyr::rename(datetime = date_time)))
+  expect_false(test_tbl_match(tbl, tbl_compare = tbl %>% dplyr::select(a, dplyr::everything())))
+  
+  expect_true(test_tbl_match(tbl, tbl_compare = tbl %>% dplyr::group_by(e, f)))
+  expect_true(test_tbl_match(tbl %>% dplyr::group_by(e, g), tbl_compare = tbl %>% dplyr::group_by(e, f)))
+  expect_true(test_tbl_match(tbl %>% dplyr::group_by(e, g), tbl_compare = tbl))
 })
 
 test_that("expect errors to be expressed by pointblank under some conditions", {
