@@ -348,7 +348,9 @@ test_that("Utility functions won't fail us", {
       "across_row_distinct_expectation_text", "across_row_distinct_failure_text", 
       "all_row_complete_expectation_text", "all_row_complete_failure_text", 
       "across_row_complete_expectation_text", "across_row_complete_failure_text", 
-      "col_schema_match_expectation_text", "col_schema_match_failure_text"
+      "col_schema_match_expectation_text", "col_schema_match_failure_text",
+      "row_count_match_expectation_text", "row_count_match_failure_text",
+      "tbl_match_expectation_text", "tbl_match_failure_text"
     )
   )
   
